from lakefs_client.paths.auth_groups_group_id.get import ApiForget
from lakefs_client.paths.auth_groups_group_id.delete import ApiFordelete


class AuthGroupsGroupId(
    ApiForget,
    ApiFordelete,
):
    pass



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from lakefs_client import schemas  # noqa: F401


class Commit(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "committer",
            "creation_date",
            "id",
            "meta_range_id",
            "message",
            "parents",
        }
        
        class properties:
            id = schemas.StrSchema
            
            
            class parents(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'parents':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            committer = schemas.StrSchema
            message = schemas.StrSchema
            creation_date = schemas.Int64Schema
            meta_range_id = schemas.StrSchema
            
            
            class metadata(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.StrSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, str, ],
                ) -> 'metadata':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "id": id,
                "parents": parents,
                "committer": committer,
                "message": message,
                "creation_date": creation_date,
                "meta_range_id": meta_range_id,
                "metadata": metadata,
            }
    
    committer: MetaOapg.properties.committer
    creation_date: MetaOapg.properties.creation_date
    id: MetaOapg.properties.id
    meta_range_id: MetaOapg.properties.meta_range_id
    message: MetaOapg.properties.message
    parents: MetaOapg.properties.parents
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["parents"]) -> MetaOapg.properties.parents: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["committer"]) -> MetaOapg.properties.committer: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["message"]) -> MetaOapg.properties.message: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["creation_date"]) -> MetaOapg.properties.creation_date: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["meta_range_id"]) -> MetaOapg.properties.meta_range_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "parents", "committer", "message", "creation_date", "meta_range_id", "metadata", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["parents"]) -> MetaOapg.properties.parents: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["committer"]) -> MetaOapg.properties.committer: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["message"]) -> MetaOapg.properties.message: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["creation_date"]) -> MetaOapg.properties.creation_date: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["meta_range_id"]) -> MetaOapg.properties.meta_range_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union[MetaOapg.properties.metadata, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "parents", "committer", "message", "creation_date", "meta_range_id", "metadata", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        committer: typing.Union[MetaOapg.properties.committer, str, ],
        creation_date: typing.Union[MetaOapg.properties.creation_date, decimal.Decimal, int, ],
        id: typing.Union[MetaOapg.properties.id, str, ],
        meta_range_id: typing.Union[MetaOapg.properties.meta_range_id, str, ],
        message: typing.Union[MetaOapg.properties.message, str, ],
        parents: typing.Union[MetaOapg.properties.parents, list, tuple, ],
        metadata: typing.Union[MetaOapg.properties.metadata, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Commit':
        return super().__new__(
            cls,
            *_args,
            committer=committer,
            creation_date=creation_date,
            id=id,
            meta_range_id=meta_range_id,
            message=message,
            parents=parents,
            metadata=metadata,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from lakefs_client import schemas  # noqa: F401


class SetupState(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            
            
            class state(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "initialized": "INITIALIZED",
                        "not_initialized": "NOT_INITIALIZED",
                        "comm_prefs_done": "COMM_PREFS_DONE",
                    }
                
                @schemas.classproperty
                def INITIALIZED(cls):
                    return cls("initialized")
                
                @schemas.classproperty
                def NOT_INITIALIZED(cls):
                    return cls("not_initialized")
                
                @schemas.classproperty
                def COMM_PREFS_DONE(cls):
                    return cls("comm_prefs_done")
        
            @staticmethod
            def login_config() -> typing.Type['LoginConfig']:
                return LoginConfig
            __annotations__ = {
                "state": state,
                "login_config": login_config,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["state"]) -> MetaOapg.properties.state: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["login_config"]) -> 'LoginConfig': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["state", "login_config", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["state"]) -> typing.Union[MetaOapg.properties.state, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["login_config"]) -> typing.Union['LoginConfig', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["state", "login_config", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        state: typing.Union[MetaOapg.properties.state, str, schemas.Unset] = schemas.unset,
        login_config: typing.Union['LoginConfig', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SetupState':
        return super().__new__(
            cls,
            *_args,
            state=state,
            login_config=login_config,
            _configuration=_configuration,
            **kwargs,
        )

from lakefs_client.model.login_config import LoginConfig



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.repositories_repository_branch_protection.post import CreateBranchProtectionRule
from lakefs_client.paths.repositories.post import CreateRepository
from lakefs_client.paths.repositories_repository_branch_protection.delete import DeleteBranchProtectionRule
from lakefs_client.paths.repositories_repository.delete import DeleteRepository
from lakefs_client.paths.repositories_repository_branch_protection.get import GetBranchProtectionRules
from lakefs_client.paths.repositories_repository.get import GetRepository
from lakefs_client.paths.repositories.get import ListRepositories


class RepositoriesApi(
    CreateBranchProtectionRule,
    CreateRepository,
    DeleteBranchProtectionRule,
    DeleteRepository,
    GetBranchProtectionRules,
    GetRepository,
    ListRepositories,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from lakefs_client.apis.tag_to_api import tag_to_api

import enum


class TagValues(str, enum.Enum):
    ACTIONS = "actions"
    AUTH = "auth"
    BRANCHES = "branches"
    COMMITS = "commits"
    CONFIG = "config"
    EXPERIMENTAL = "experimental"
    OTF_DIFF = "otf diff"
    HEALTH_CHECK = "healthCheck"
    IMPORT = "import"
    METADATA = "metadata"
    OBJECTS = "objects"
    REFS = "refs"
    REPOSITORIES = "repositories"
    RETENTION = "retention"
    STAGING = "staging"
    STATISTICS = "statistics"
    TAGS = "tags"
    TEMPLATES = "templates"



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.repositories_repository_otf_refs_left_ref_diff_right_ref.get import OtfDiff


class ExperimentalApi(
    OtfDiff,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

import unittest
from unittest.mock import patch

import urllib3

import lakefs_client
from lakefs_client.paths.repositories_repository_refs_source_ref_merge_destination_branch import post  # noqa: E501
from lakefs_client import configuration, schemas, api_client

from .. import ApiTestMixin


class TestRepositoriesRepositoryRefsSourceRefMergeDestinationBranch(ApiTestMixin, unittest.TestCase):
    """
    RepositoriesRepositoryRefsSourceRefMergeDestinationBranch unit test stubs
        merge references  # noqa: E501
    """
    _configuration = configuration.Configuration()

    def setUp(self):
        used_api_client = api_client.ApiClient(configuration=self._configuration)
        self.api = post.ApiForpost(api_client=used_api_client)  # noqa: E501

    def tearDown(self):
        pass

    response_status = 200




if __name__ == '__main__':
    unittest.main()



from lakefs_client.paths.repositories_repository_tags_tag.get import ApiForget
from lakefs_client.paths.repositories_repository_tags_tag.delete import ApiFordelete


class RepositoriesRepositoryTagsTag(
    ApiForget,
    ApiFordelete,
):
    pass



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from lakefs_client import schemas  # noqa: F401


class OtfDiffList(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "results",
        }
        
        class properties:
            
            
            class results(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['OtfDiffEntry']:
                        return OtfDiffEntry
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['OtfDiffEntry'], typing.List['OtfDiffEntry']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'results':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'OtfDiffEntry':
                    return super().__getitem__(i)
            
            
            class diff_type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "created": "CREATED",
                        "dropped": "DROPPED",
                        "changed": "CHANGED",
                    }
                
                @schemas.classproperty
                def CREATED(cls):
                    return cls("created")
                
                @schemas.classproperty
                def DROPPED(cls):
                    return cls("dropped")
                
                @schemas.classproperty
                def CHANGED(cls):
                    return cls("changed")
            __annotations__ = {
                "results": results,
                "diff_type": diff_type,
            }
    
    results: MetaOapg.properties.results
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["results"]) -> MetaOapg.properties.results: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["diff_type"]) -> MetaOapg.properties.diff_type: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["results", "diff_type", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["results"]) -> MetaOapg.properties.results: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["diff_type"]) -> typing.Union[MetaOapg.properties.diff_type, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["results", "diff_type", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        results: typing.Union[MetaOapg.properties.results, list, tuple, ],
        diff_type: typing.Union[MetaOapg.properties.diff_type, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'OtfDiffList':
        return super().__new__(
            cls,
            *_args,
            results=results,
            diff_type=diff_type,
            _configuration=_configuration,
            **kwargs,
        )

from lakefs_client.model.otf_diff_entry import OtfDiffEntry



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.config_garbage_collection.get import GetGarbageCollectionConfig
from lakefs_client.paths.config_version.get import GetLakeFsVersion
from lakefs_client.paths.setup_lakefs.get import GetSetupState
from lakefs_client.paths.config_storage.get import GetStorageConfig
from lakefs_client.paths.setup_lakefs.post import Setup
from lakefs_client.paths.setup_comm_prefs.post import SetupCommPrefs


class ConfigApi(
    GetGarbageCollectionConfig,
    GetLakeFsVersion,
    GetSetupState,
    GetStorageConfig,
    Setup,
    SetupCommPrefs,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



from lakefs_client.paths.auth_users_user_id.get import ApiForget
from lakefs_client.paths.auth_users_user_id.delete import ApiFordelete


class AuthUsersUserId(
    ApiForget,
    ApiFordelete,
):
    pass



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.repositories_repository_branches_branch_cherry_pick.post import CherryPick
from lakefs_client.paths.repositories_repository_branches.post import CreateBranch
from lakefs_client.paths.repositories_repository_branches_branch.delete import DeleteBranch
from lakefs_client.paths.repositories_repository_branches_branch_diff.get import DiffBranch
from lakefs_client.paths.repositories_repository_branches_branch.get import GetBranch
from lakefs_client.paths.repositories_repository_branches.get import ListBranches
from lakefs_client.paths.repositories_repository_branches_branch.put import ResetBranch
from lakefs_client.paths.repositories_repository_branches_branch_revert.post import RevertBranch


class BranchesApi(
    CherryPick,
    CreateBranch,
    DeleteBranch,
    DiffBranch,
    GetBranch,
    ListBranches,
    ResetBranch,
    RevertBranch,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.repositories_repository_refs_left_ref_diff_right_ref.get import DiffRefs
from lakefs_client.paths.repositories_repository_refs_dump.put import DumpRefs
from lakefs_client.paths.repositories_repository_refs_source_ref_merge_destination_branch.get import FindMergeBase
from lakefs_client.paths.repositories_repository_refs_ref_commits.get import LogCommits
from lakefs_client.paths.repositories_repository_refs_source_ref_merge_destination_branch.post import MergeIntoBranch
from lakefs_client.paths.repositories_repository_refs_restore.put import RestoreRefs


class RefsApi(
    DiffRefs,
    DumpRefs,
    FindMergeBase,
    LogCommits,
    MergeIntoBranch,
    RestoreRefs,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from lakefs_client import schemas  # noqa: F401


class OtfDiffEntry(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "operation_content",
            "operation_type",
            "id",
            "operation",
            "timestamp",
        }
        
        class properties:
            id = schemas.StrSchema
            timestamp = schemas.IntSchema
            operation = schemas.StrSchema
            operation_content = schemas.DictSchema
            
            
            class operation_type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "create": "CREATE",
                        "update": "UPDATE",
                        "delete": "DELETE",
                    }
                
                @schemas.classproperty
                def CREATE(cls):
                    return cls("create")
                
                @schemas.classproperty
                def UPDATE(cls):
                    return cls("update")
                
                @schemas.classproperty
                def DELETE(cls):
                    return cls("delete")
            __annotations__ = {
                "id": id,
                "timestamp": timestamp,
                "operation": operation,
                "operation_content": operation_content,
                "operation_type": operation_type,
            }
    
    operation_content: MetaOapg.properties.operation_content
    operation_type: MetaOapg.properties.operation_type
    id: MetaOapg.properties.id
    operation: MetaOapg.properties.operation
    timestamp: MetaOapg.properties.timestamp
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["timestamp"]) -> MetaOapg.properties.timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["operation"]) -> MetaOapg.properties.operation: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["operation_content"]) -> MetaOapg.properties.operation_content: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["operation_type"]) -> MetaOapg.properties.operation_type: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "timestamp", "operation", "operation_content", "operation_type", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["timestamp"]) -> MetaOapg.properties.timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["operation"]) -> MetaOapg.properties.operation: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["operation_content"]) -> MetaOapg.properties.operation_content: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["operation_type"]) -> MetaOapg.properties.operation_type: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "timestamp", "operation", "operation_content", "operation_type", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        operation_content: typing.Union[MetaOapg.properties.operation_content, dict, frozendict.frozendict, ],
        operation_type: typing.Union[MetaOapg.properties.operation_type, str, ],
        id: typing.Union[MetaOapg.properties.id, str, ],
        operation: typing.Union[MetaOapg.properties.operation, str, ],
        timestamp: typing.Union[MetaOapg.properties.timestamp, decimal.Decimal, int, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'OtfDiffEntry':
        return super().__new__(
            cls,
            *_args,
            operation_content=operation_content,
            operation_type=operation_type,
            id=id,
            operation=operation,
            timestamp=timestamp,
            _configuration=_configuration,
            **kwargs,
        )



from lakefs_client.paths.repositories_repository_branches.get import ApiForget
from lakefs_client.paths.repositories_repository_branches.post import ApiForpost


class RepositoriesRepositoryBranches(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from lakefs_client import schemas  # noqa: F401


class StorageConfig(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "blockstore_namespace_ValidityRegex",
            "blockstore_namespace_example",
            "blockstore_type",
            "import_support",
            "pre_sign_support_UI",
            "pre_sign_support",
        }
        
        class properties:
            blockstore_type = schemas.StrSchema
            blockstore_namespace_example = schemas.StrSchema
            blockstore_namespace_ValidityRegex = schemas.StrSchema
            pre_sign_support = schemas.BoolSchema
            pre_sign_support_UI = schemas.BoolSchema
            import_support = schemas.BoolSchema
            default_namespace_prefix = schemas.StrSchema
            __annotations__ = {
                "blockstore_type": blockstore_type,
                "blockstore_namespace_example": blockstore_namespace_example,
                "blockstore_namespace_ValidityRegex": blockstore_namespace_ValidityRegex,
                "pre_sign_support": pre_sign_support,
                "pre_sign_support_UI": pre_sign_support_UI,
                "import_support": import_support,
                "default_namespace_prefix": default_namespace_prefix,
            }
    
    blockstore_namespace_ValidityRegex: MetaOapg.properties.blockstore_namespace_ValidityRegex
    blockstore_namespace_example: MetaOapg.properties.blockstore_namespace_example
    blockstore_type: MetaOapg.properties.blockstore_type
    import_support: MetaOapg.properties.import_support
    pre_sign_support_UI: MetaOapg.properties.pre_sign_support_UI
    pre_sign_support: MetaOapg.properties.pre_sign_support
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["blockstore_type"]) -> MetaOapg.properties.blockstore_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["blockstore_namespace_example"]) -> MetaOapg.properties.blockstore_namespace_example: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["blockstore_namespace_ValidityRegex"]) -> MetaOapg.properties.blockstore_namespace_ValidityRegex: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["pre_sign_support"]) -> MetaOapg.properties.pre_sign_support: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["pre_sign_support_UI"]) -> MetaOapg.properties.pre_sign_support_UI: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["import_support"]) -> MetaOapg.properties.import_support: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["default_namespace_prefix"]) -> MetaOapg.properties.default_namespace_prefix: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["blockstore_type", "blockstore_namespace_example", "blockstore_namespace_ValidityRegex", "pre_sign_support", "pre_sign_support_UI", "import_support", "default_namespace_prefix", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["blockstore_type"]) -> MetaOapg.properties.blockstore_type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["blockstore_namespace_example"]) -> MetaOapg.properties.blockstore_namespace_example: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["blockstore_namespace_ValidityRegex"]) -> MetaOapg.properties.blockstore_namespace_ValidityRegex: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["pre_sign_support"]) -> MetaOapg.properties.pre_sign_support: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["pre_sign_support_UI"]) -> MetaOapg.properties.pre_sign_support_UI: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["import_support"]) -> MetaOapg.properties.import_support: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["default_namespace_prefix"]) -> typing.Union[MetaOapg.properties.default_namespace_prefix, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["blockstore_type", "blockstore_namespace_example", "blockstore_namespace_ValidityRegex", "pre_sign_support", "pre_sign_support_UI", "import_support", "default_namespace_prefix", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        blockstore_namespace_ValidityRegex: typing.Union[MetaOapg.properties.blockstore_namespace_ValidityRegex, str, ],
        blockstore_namespace_example: typing.Union[MetaOapg.properties.blockstore_namespace_example, str, ],
        blockstore_type: typing.Union[MetaOapg.properties.blockstore_type, str, ],
        import_support: typing.Union[MetaOapg.properties.import_support, bool, ],
        pre_sign_support_UI: typing.Union[MetaOapg.properties.pre_sign_support_UI, bool, ],
        pre_sign_support: typing.Union[MetaOapg.properties.pre_sign_support, bool, ],
        default_namespace_prefix: typing.Union[MetaOapg.properties.default_namespace_prefix, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'StorageConfig':
        return super().__new__(
            cls,
            *_args,
            blockstore_namespace_ValidityRegex=blockstore_namespace_ValidityRegex,
            blockstore_namespace_example=blockstore_namespace_example,
            blockstore_type=blockstore_type,
            import_support=import_support,
            pre_sign_support_UI=pre_sign_support_UI,
            pre_sign_support=pre_sign_support,
            default_namespace_prefix=default_namespace_prefix,
            _configuration=_configuration,
            **kwargs,
        )



from lakefs_client.paths.auth_users_user_id_credentials_access_key_id.get import ApiForget
from lakefs_client.paths.auth_users_user_id_credentials_access_key_id.delete import ApiFordelete


class AuthUsersUserIdCredentialsAccessKeyId(
    ApiForget,
    ApiFordelete,
):
    pass



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from lakefs_client import schemas  # noqa: F401


class LoginConfig(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "logout_url",
            "login_url",
            "login_cookie_names",
        }
        
        class properties:
            login_url = schemas.StrSchema
            
            
            class login_cookie_names(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'login_cookie_names':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            logout_url = schemas.StrSchema
            
            
            class RBAC(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "simplified": "SIMPLIFIED",
                        "external": "EXTERNAL",
                    }
                
                @schemas.classproperty
                def SIMPLIFIED(cls):
                    return cls("simplified")
                
                @schemas.classproperty
                def EXTERNAL(cls):
                    return cls("external")
            login_failed_message = schemas.StrSchema
            fallback_login_url = schemas.StrSchema
            fallback_login_label = schemas.StrSchema
            __annotations__ = {
                "login_url": login_url,
                "login_cookie_names": login_cookie_names,
                "logout_url": logout_url,
                "RBAC": RBAC,
                "login_failed_message": login_failed_message,
                "fallback_login_url": fallback_login_url,
                "fallback_login_label": fallback_login_label,
            }
    
    logout_url: MetaOapg.properties.logout_url
    login_url: MetaOapg.properties.login_url
    login_cookie_names: MetaOapg.properties.login_cookie_names
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["login_url"]) -> MetaOapg.properties.login_url: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["login_cookie_names"]) -> MetaOapg.properties.login_cookie_names: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["logout_url"]) -> MetaOapg.properties.logout_url: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["RBAC"]) -> MetaOapg.properties.RBAC: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["login_failed_message"]) -> MetaOapg.properties.login_failed_message: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fallback_login_url"]) -> MetaOapg.properties.fallback_login_url: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fallback_login_label"]) -> MetaOapg.properties.fallback_login_label: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["login_url", "login_cookie_names", "logout_url", "RBAC", "login_failed_message", "fallback_login_url", "fallback_login_label", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["login_url"]) -> MetaOapg.properties.login_url: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["login_cookie_names"]) -> MetaOapg.properties.login_cookie_names: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["logout_url"]) -> MetaOapg.properties.logout_url: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["RBAC"]) -> typing.Union[MetaOapg.properties.RBAC, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["login_failed_message"]) -> typing.Union[MetaOapg.properties.login_failed_message, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fallback_login_url"]) -> typing.Union[MetaOapg.properties.fallback_login_url, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fallback_login_label"]) -> typing.Union[MetaOapg.properties.fallback_login_label, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["login_url", "login_cookie_names", "logout_url", "RBAC", "login_failed_message", "fallback_login_url", "fallback_login_label", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        logout_url: typing.Union[MetaOapg.properties.logout_url, str, ],
        login_url: typing.Union[MetaOapg.properties.login_url, str, ],
        login_cookie_names: typing.Union[MetaOapg.properties.login_cookie_names, list, tuple, ],
        RBAC: typing.Union[MetaOapg.properties.RBAC, str, schemas.Unset] = schemas.unset,
        login_failed_message: typing.Union[MetaOapg.properties.login_failed_message, str, schemas.Unset] = schemas.unset,
        fallback_login_url: typing.Union[MetaOapg.properties.fallback_login_url, str, schemas.Unset] = schemas.unset,
        fallback_login_label: typing.Union[MetaOapg.properties.fallback_login_label, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'LoginConfig':
        return super().__new__(
            cls,
            *_args,
            logout_url=logout_url,
            login_url=login_url,
            login_cookie_names=login_cookie_names,
            RBAC=RBAC,
            login_failed_message=login_failed_message,
            fallback_login_url=fallback_login_url,
            fallback_login_label=fallback_login_label,
            _configuration=_configuration,
            **kwargs,
        )



from lakefs_client.paths.repositories_repository_refs_ref_objects.get import ApiForget
from lakefs_client.paths.repositories_repository_refs_ref_objects.head import ApiForhead


class RepositoriesRepositoryRefsRefObjects(
    ApiForget,
    ApiForhead,
):
    pass



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.repositories_repository_refs_branch_symlink.post import CreateSymlinkFile
from lakefs_client.paths.repositories_repository_metadata_meta_range_meta_range.get import GetMetaRange
from lakefs_client.paths.repositories_repository_metadata_range_range.get import GetRange


class MetadataApi(
    CreateSymlinkFile,
    GetMetaRange,
    GetRange,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



import typing_extensions

from lakefs_client.apis.tags import TagValues
from lakefs_client.apis.tags.actions_api import ActionsApi
from lakefs_client.apis.tags.auth_api import AuthApi
from lakefs_client.apis.tags.branches_api import BranchesApi
from lakefs_client.apis.tags.commits_api import CommitsApi
from lakefs_client.apis.tags.config_api import ConfigApi
from lakefs_client.apis.tags.experimental_api import ExperimentalApi
from lakefs_client.apis.tags.otf_diff_api import OtfDiffApi
from lakefs_client.apis.tags.health_check_api import HealthCheckApi
from lakefs_client.apis.tags.model_import_api import ModelImportApi
from lakefs_client.apis.tags.metadata_api import MetadataApi
from lakefs_client.apis.tags.objects_api import ObjectsApi
from lakefs_client.apis.tags.refs_api import RefsApi
from lakefs_client.apis.tags.repositories_api import RepositoriesApi
from lakefs_client.apis.tags.retention_api import RetentionApi
from lakefs_client.apis.tags.staging_api import StagingApi
from lakefs_client.apis.tags.statistics_api import StatisticsApi
from lakefs_client.apis.tags.tags_api import TagsApi
from lakefs_client.apis.tags.templates_api import TemplatesApi

TagToApi = typing_extensions.TypedDict(
    'TagToApi',
    {
        TagValues.ACTIONS: ActionsApi,
        TagValues.AUTH: AuthApi,
        TagValues.BRANCHES: BranchesApi,
        TagValues.COMMITS: CommitsApi,
        TagValues.CONFIG: ConfigApi,
        TagValues.EXPERIMENTAL: ExperimentalApi,
        TagValues.OTF_DIFF: OtfDiffApi,
        TagValues.HEALTH_CHECK: HealthCheckApi,
        TagValues.IMPORT: ModelImportApi,
        TagValues.METADATA: MetadataApi,
        TagValues.OBJECTS: ObjectsApi,
        TagValues.REFS: RefsApi,
        TagValues.REPOSITORIES: RepositoriesApi,
        TagValues.RETENTION: RetentionApi,
        TagValues.STAGING: StagingApi,
        TagValues.STATISTICS: StatisticsApi,
        TagValues.TAGS: TagsApi,
        TagValues.TEMPLATES: TemplatesApi,
    }
)

tag_to_api = TagToApi(
    {
        TagValues.ACTIONS: ActionsApi,
        TagValues.AUTH: AuthApi,
        TagValues.BRANCHES: BranchesApi,
        TagValues.COMMITS: CommitsApi,
        TagValues.CONFIG: ConfigApi,
        TagValues.EXPERIMENTAL: ExperimentalApi,
        TagValues.OTF_DIFF: OtfDiffApi,
        TagValues.HEALTH_CHECK: HealthCheckApi,
        TagValues.IMPORT: ModelImportApi,
        TagValues.METADATA: MetadataApi,
        TagValues.OBJECTS: ObjectsApi,
        TagValues.REFS: RefsApi,
        TagValues.REPOSITORIES: RepositoriesApi,
        TagValues.RETENTION: RetentionApi,
        TagValues.STAGING: StagingApi,
        TagValues.STATISTICS: StatisticsApi,
        TagValues.TAGS: TagsApi,
        TagValues.TEMPLATES: TemplatesApi,
    }
)



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.auth_groups_group_id_members_user_id.put import AddGroupMembership
from lakefs_client.paths.auth_groups_group_id_policies_policy_id.put import AttachPolicyToGroup
from lakefs_client.paths.auth_users_user_id_policies_policy_id.put import AttachPolicyToUser
from lakefs_client.paths.auth_users_user_id_credentials.post import CreateCredentials
from lakefs_client.paths.auth_groups.post import CreateGroup
from lakefs_client.paths.auth_policies.post import CreatePolicy
from lakefs_client.paths.auth_users.post import CreateUser
from lakefs_client.paths.auth_users_user_id_credentials_access_key_id.delete import DeleteCredentials
from lakefs_client.paths.auth_groups_group_id.delete import DeleteGroup
from lakefs_client.paths.auth_groups_group_id_members_user_id.delete import DeleteGroupMembership
from lakefs_client.paths.auth_policies_policy_id.delete import DeletePolicy
from lakefs_client.paths.auth_users_user_id.delete import DeleteUser
from lakefs_client.paths.auth_groups_group_id_policies_policy_id.delete import DetachPolicyFromGroup
from lakefs_client.paths.auth_users_user_id_policies_policy_id.delete import DetachPolicyFromUser
from lakefs_client.paths.auth_password_forgot.post import ForgotPassword
from lakefs_client.paths.auth_capabilities.get import GetAuthCapabilities
from lakefs_client.paths.auth_users_user_id_credentials_access_key_id.get import GetCredentials
from lakefs_client.paths.user.get import GetCurrentUser
from lakefs_client.paths.auth_groups_group_id.get import GetGroup
from lakefs_client.paths.auth_policies_policy_id.get import GetPolicy
from lakefs_client.paths.auth_users_user_id.get import GetUser
from lakefs_client.paths.auth_groups_group_id_members.get import ListGroupMembers
from lakefs_client.paths.auth_groups_group_id_policies.get import ListGroupPolicies
from lakefs_client.paths.auth_groups.get import ListGroups
from lakefs_client.paths.auth_policies.get import ListPolicies
from lakefs_client.paths.auth_users_user_id_credentials.get import ListUserCredentials
from lakefs_client.paths.auth_users_user_id_groups.get import ListUserGroups
from lakefs_client.paths.auth_users_user_id_policies.get import ListUserPolicies
from lakefs_client.paths.auth_users.get import ListUsers
from lakefs_client.paths.auth_login.post import Login
from lakefs_client.paths.auth_password.post import UpdatePassword
from lakefs_client.paths.auth_policies_policy_id.put import UpdatePolicy


class AuthApi(
    AddGroupMembership,
    AttachPolicyToGroup,
    AttachPolicyToUser,
    CreateCredentials,
    CreateGroup,
    CreatePolicy,
    CreateUser,
    DeleteCredentials,
    DeleteGroup,
    DeleteGroupMembership,
    DeletePolicy,
    DeleteUser,
    DetachPolicyFromGroup,
    DetachPolicyFromUser,
    ForgotPassword,
    GetAuthCapabilities,
    GetCredentials,
    GetCurrentUser,
    GetGroup,
    GetPolicy,
    GetUser,
    ListGroupMembers,
    ListGroupPolicies,
    ListGroups,
    ListPolicies,
    ListUserCredentials,
    ListUserGroups,
    ListUserPolicies,
    ListUsers,
    Login,
    UpdatePassword,
    UpdatePolicy,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from lakefs_client import schemas  # noqa: F401


class Statement(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "resource",
            "effect",
            "action",
        }
        
        class properties:
            
            
            class effect(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "allow": "ALLOW",
                        "deny": "DENY",
                    }
                
                @schemas.classproperty
                def ALLOW(cls):
                    return cls("allow")
                
                @schemas.classproperty
                def DENY(cls):
                    return cls("deny")
            resource = schemas.StrSchema
            
            
            class action(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    min_items = 1
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'action':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            __annotations__ = {
                "effect": effect,
                "resource": resource,
                "action": action,
            }
    
    resource: MetaOapg.properties.resource
    effect: MetaOapg.properties.effect
    action: MetaOapg.properties.action
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["effect"]) -> MetaOapg.properties.effect: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["resource"]) -> MetaOapg.properties.resource: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["action"]) -> MetaOapg.properties.action: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["effect", "resource", "action", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["effect"]) -> MetaOapg.properties.effect: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["resource"]) -> MetaOapg.properties.resource: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["action"]) -> MetaOapg.properties.action: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["effect", "resource", "action", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        resource: typing.Union[MetaOapg.properties.resource, str, ],
        effect: typing.Union[MetaOapg.properties.effect, str, ],
        action: typing.Union[MetaOapg.properties.action, list, tuple, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Statement':
        return super().__new__(
            cls,
            *_args,
            resource=resource,
            effect=effect,
            action=action,
            _configuration=_configuration,
            **kwargs,
        )



from lakefs_client.paths.auth_groups_group_id_policies_policy_id.put import ApiForput
from lakefs_client.paths.auth_groups_group_id_policies_policy_id.delete import ApiFordelete


class AuthGroupsGroupIdPoliciesPolicyId(
    ApiForput,
    ApiFordelete,
):
    pass



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.repositories_repository_gc_rules.delete import DeleteGarbageCollectionRules
from lakefs_client.paths.repositories_repository_gc_rules.get import GetGarbageCollectionRules
from lakefs_client.paths.repositories_repository_gc_prepare_commits.post import PrepareGarbageCollectionCommits
from lakefs_client.paths.repositories_repository_gc_prepare_uncommited.post import PrepareGarbageCollectionUncommitted
from lakefs_client.paths.repositories_repository_gc_rules.post import SetGarbageCollectionRules


class RetentionApi(
    DeleteGarbageCollectionRules,
    GetGarbageCollectionRules,
    PrepareGarbageCollectionCommits,
    PrepareGarbageCollectionUncommitted,
    SetGarbageCollectionRules,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
